@@ -3,12 +3,14 @@ package commands
 import (
 	"fmt"
 	"os"
+	"path/filepath"
 
 	"github.com/git-lfs/git-lfs/v3/errors"
 	"github.com/git-lfs/git-lfs/v3/filepathfilter"
 	"github.com/git-lfs/git-lfs/v3/git"
 	"github.com/git-lfs/git-lfs/v3/lfs"
 	"github.com/git-lfs/git-lfs/v3/tasklog"
+	"github.com/git-lfs/git-lfs/v3/tools"
 	"github.com/git-lfs/git-lfs/v3/tq"
 	"github.com/git-lfs/git-lfs/v3/tr"
 	"github.com/spf13/cobra"
@@ -24,16 +26,27 @@ var (
 func checkoutCommand(cmd *cobra.Command, args []string) {
 	setupRepository()
 
+	// TODO: After suitable advance public notice, replace this block
+	// and the preceding call to setupRepository() with a single call to
+	// setupWorkingCopy(), which will perform the same check for a bare
+	// repository but will exit non-zero, as other commands already do.
+	if cfg.LocalWorkingDir() == "" {
+		Print(tr.Tr.Get("This operation must be run in a work tree."))
+		os.Exit(0)
+	}
+
 	stage, err := whichCheckout()
 	if err != nil {
 		Exit(tr.Tr.Get("Error parsing args: %v", err))
 	}
 
+	rootedPaths := rootedPaths(args)
+
 	if checkoutTo != "" && stage != git.IndexStageDefault {
 		if len(args) != 1 {
 			Exit(tr.Tr.Get("--to requires exactly one Git LFS object file path"))
 		}
-		checkoutConflict(rootedPaths(args)[0], stage)
+		checkoutConflict(rootedPaths[0], stage)
 		return
 	} else if checkoutTo != "" || stage != git.IndexStageDefault {
 		Exit(tr.Tr.Get("--to and exactly one of --theirs, --ours, and --base must be used together"))
@@ -44,6 +57,7 @@ func checkoutCommand(cmd *cobra.Command, args []string) {
 		Panic(err, tr.Tr.Get("Could not checkout"))
 	}
 
+	// will chdir to root of working tree, if one exists
 	singleCheckout := newSingleCheckout(cfg.Git, "")
 	if singleCheckout.Skip() {
 		fmt.Println(tr.Tr.Get("Cannot checkout LFS objects, Git LFS is not installed."))
@@ -71,7 +85,7 @@ func checkoutCommand(cmd *cobra.Command, args []string) {
 		pointers = append(pointers, p)
 	})
 
-	chgitscanner.Filter = filepathfilter.New(rootedPaths(args), nil, filepathfilter.GitIgnore)
+	chgitscanner.Filter = filepathfilter.New(rootedPaths, nil, filepathfilter.GitIgnore)
 
 	if err := chgitscanner.ScanLFSFiles(ref.Sha, nil); err != nil {
 		ExitWithError(err)
@@ -92,6 +106,17 @@ func checkoutCommand(cmd *cobra.Command, args []string) {
 }
 
 func checkoutConflict(file string, stage git.IndexStage) {
+	checkoutTo, err := filepath.Abs(checkoutTo)
+	if err != nil {
+		Exit(tr.Tr.Get("Could not convert %q to absolute path: %v", checkoutTo, err))
+	}
+
+	err = tools.MkdirAll(filepath.Dir(checkoutTo), cfg)
+	if err != nil {
+		Exit(tr.Tr.Get("Could not create path %q: %v", checkoutTo, err))
+	}
+
+	// will chdir to root of working tree, if one exists
 	singleCheckout := newSingleCheckout(cfg.Git, "")
 	if singleCheckout.Skip() {
 		fmt.Println(tr.Tr.Get("Cannot checkout LFS objects, Git LFS is not installed."))
