@@ -7,12 +7,11 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/git-lfs/git-lfs/lfs"
-	"github.com/git-lfs/git-lfs/localstorage"
-	"github.com/git-lfs/git-lfs/subprocess"
+	"github.com/git-lfs/git-lfs/v3/subprocess"
+	"github.com/git-lfs/git-lfs/v3/tr"
 
-	"github.com/git-lfs/git-lfs/git"
-	"github.com/git-lfs/git-lfs/tools"
+	"github.com/git-lfs/git-lfs/v3/git"
+	"github.com/git-lfs/git-lfs/v3/tools"
 	"github.com/spf13/cobra"
 )
 
@@ -25,28 +24,28 @@ var (
 func cloneCommand(cmd *cobra.Command, args []string) {
 	requireGitVersion()
 
-	if git.Config.IsGitVersionAtLeast("2.15.0") {
-		msg := []string{
-			"WARNING: 'git lfs clone' is deprecated and will not be updated",
-			"          with new flags from 'git clone'",
-			"",
-			"'git clone' has been updated in upstream Git to have comparable",
-			"speeds to 'git lfs clone'.",
-		}
+	if git.IsGitVersionAtLeast("2.15.0") {
+		// TRANSLATORS: Individual lines should not exceed 80
+		// characters, and any additional lines in the first message
+		// should be indented to align with the first line's text
+		// following the warning prefix and punctuation.
+		msg := fmt.Sprintf("%s\n\n%s",
+			tr.Tr.Get("WARNING: `git lfs clone` is deprecated and will not be updated\n          with new flags from `git clone`"),
+			tr.Tr.Get("`git clone` has been updated in upstream Git to have comparable\nspeeds to `git lfs clone`."))
 
-		fmt.Fprintln(os.Stderr, strings.Join(msg, "\n"))
+		fmt.Fprintln(os.Stderr, msg)
 	}
 
 	// We pass all args to git clone
 	err := git.CloneWithoutFilters(cloneFlags, args)
 	if err != nil {
-		Exit("Error(s) during clone:\n%v", err)
+		Exit("%s\n%v", tr.Tr.Get("Error(s) during clone:"), err)
 	}
 
 	// now execute pull (need to be inside dir)
 	cwd, err := tools.Getwd()
 	if err != nil {
-		Exit("Unable to derive current working dir: %v", err)
+		Exit(tr.Tr.Get("Unable to derive current working dir: %v", err))
 	}
 
 	// Either the last argument was a relative or local dir, or we have to
@@ -60,43 +59,36 @@ func cloneCommand(cmd *cobra.Command, args []string) {
 		}
 		clonedir, _ = filepath.Abs(base)
 		if !tools.DirExists(clonedir) {
-			Exit("Unable to find clone dir at %q", clonedir)
+			Exit(tr.Tr.Get("Unable to find clone dir at %q", clonedir))
 		}
 	}
 
 	err = os.Chdir(clonedir)
 	if err != nil {
-		Exit("Unable to change directory to clone dir %q: %v", clonedir, err)
+		Exit(tr.Tr.Get("Unable to change directory to clone dir %q: %v", clonedir, err))
 	}
 
 	// Make sure we pop back to dir we started in at the end
 	defer os.Chdir(cwd)
 
-	// Also need to derive dirs now
-	localstorage.ResolveDirs()
-	requireInRepo()
+	setupRepository()
 
-	// Now just call pull with default args
 	// Support --origin option to clone
-	var remote string
 	if len(cloneFlags.Origin) > 0 {
-		remote = cloneFlags.Origin
-	} else {
-		remote = "origin"
+		cfg.SetRemote(cloneFlags.Origin)
 	}
 
 	if ref, err := git.CurrentRef(); err == nil {
 		includeArg, excludeArg := getIncludeExcludeArgs(cmd)
-		filter := buildFilepathFilter(cfg, includeArg, excludeArg)
+		filter := buildFilepathFilter(cfg, includeArg, excludeArg, true)
 		if cloneFlags.NoCheckout || cloneFlags.Bare {
 			// If --no-checkout or --bare then we shouldn't check out, just fetch instead
-			cfg.CurrentRemote = remote
-			fetchRef(ref.Name, filter)
+			fetchRef(ref.Name, filter, nil)
 		} else {
-			pull(remote, filter)
+			pull(filter)
 			err := postCloneSubmodules(args)
 			if err != nil {
-				Exit("Error performing 'git lfs pull' for submodules: %v", err)
+				Exit(tr.Tr.Get("Error performing `git lfs pull` for submodules: %v", err))
 			}
 		}
 	}
@@ -105,7 +97,7 @@ func cloneCommand(cmd *cobra.Command, args []string) {
 		// If --skip-repo wasn't given, install repo-level hooks while
 		// we're still in the checkout directory.
 
-		if err := lfs.InstallHooks(false); err != nil {
+		if err := installHooks(false); err != nil {
 			ExitWithError(err)
 		}
 	}
@@ -114,7 +106,7 @@ func cloneCommand(cmd *cobra.Command, args []string) {
 func postCloneSubmodules(args []string) error {
 	// In git 2.9+ the filter option will have been passed through to submodules
 	// So we need to lfs pull inside each
-	if !git.Config.IsGitVersionAtLeast("2.9.0") {
+	if !git.IsGitVersionAtLeast("2.9.0") {
 		// In earlier versions submodules would have used smudge filter
 		return nil
 	}
@@ -126,8 +118,11 @@ func postCloneSubmodules(args []string) error {
 	// Use `git submodule foreach --recursive` to cascade into nested submodules
 	// Also good to call a new instance of git-lfs rather than do things
 	// inside this instance, since that way we get a clean env in that subrepo
-	cmd := subprocess.ExecCommand("git", "submodule", "foreach", "--recursive",
+	cmd, err := subprocess.ExecCommand("git", "submodule", "foreach", "--recursive",
 		"git lfs pull")
+	if err != nil {
+		return err
+	}
 	cmd.Stderr = os.Stderr
 	cmd.Stdin = os.Stdin
 	cmd.Stdout = os.Stdout
