@@ -1,10 +1,12 @@
 package commands
 
 import (
-	"fmt"
+	"encoding/json"
 	"os"
+	"sync"
 	"time"
 
+	"github.com/git-lfs/git-lfs/v3/errors"
 	"github.com/git-lfs/git-lfs/v3/filepathfilter"
 	"github.com/git-lfs/git-lfs/v3/git"
 	"github.com/git-lfs/git-lfs/v3/lfs"
@@ -16,11 +18,62 @@ import (
 )
 
 var (
-	fetchRecentArg bool
-	fetchAllArg    bool
-	fetchPruneArg  bool
+	fetchRecentArg  bool
+	fetchAllArg     bool
+	fetchPruneArg   bool
+	fetchRefetchArg bool
+	fetchDryRunArg  bool
+	fetchJsonArg    bool
 )
 
+type fetchWatcher struct {
+	transfers []*tq.Transfer
+	observed  map[string]bool
+}
+
+func (d *fetchWatcher) registerTransfer(t *tq.Transfer) {
+	if fetchJsonArg {
+		d.transfers = append(d.transfers, t)
+	}
+	if fetchDryRunArg || fetchRefetchArg {
+		if d.observed == nil {
+			d.observed = make(map[string]bool)
+		}
+		d.observed[t.Oid] = true
+	}
+	if fetchDryRunArg {
+		printProgress("%s %s => %s", tr.Tr.Get("fetch"), t.Oid, t.Name)
+	}
+}
+
+func (d *fetchWatcher) dumpJson() {
+	data := struct {
+		Transfers []*tq.Transfer `json:"transfers"`
+	}{Transfers: d.transfers}
+	if data.Transfers == nil {
+		data.Transfers = []*tq.Transfer{}
+	}
+	encoder := json.NewEncoder(os.Stdout)
+	encoder.SetIndent("", " ")
+	if err := encoder.Encode(data); err != nil {
+		ExitWithError(err)
+	}
+}
+
+func (d *fetchWatcher) hasObserved(oid string) bool {
+	return d.observed[oid]
+}
+
+func hasToPrintTransfers() bool {
+	return fetchJsonArg || fetchDryRunArg
+}
+
+func printProgress(format string, args ...interface{}) {
+	// TODO: Adjust all our commands to use a common function to output
+	//       progress messages to stderr, following Git's model.
+	Error(format, args...)
+}
+
 func getIncludeExcludeArgs(cmd *cobra.Command) (include, exclude *string) {
 	includeFlag := cmd.Flag("include")
 	excludeFlag := cmd.Flag("exclude")
@@ -60,10 +113,17 @@ func fetchCommand(cmd *cobra.Command, args []string) {
 		refs = []*git.Ref{ref}
 	}
 
+	if fetchJsonArg && fetchPruneArg {
+		// git lfs prune has no `--json` flag, so let's not allow that here for the moment
+		Exit(tr.Tr.Get("Cannot combine --json with --prune"))
+	}
+
 	success := true
 	include, exclude := getIncludeExcludeArgs(cmd)
 	fetchPruneCfg := lfs.NewFetchPruneConfig(cfg.Git)
 
+	watcher := &fetchWatcher{}
+
 	if fetchAllArg {
 		if fetchRecentArg {
 			Exit(tr.Tr.Get("Cannot combine --all with --recent"))
@@ -72,7 +132,7 @@ func fetchCommand(cmd *cobra.Command, args []string) {
 			Exit(tr.Tr.Get("Cannot combine --all with --include or --exclude"))
 		}
 		if len(cfg.FetchIncludePaths()) > 0 || len(cfg.FetchExcludePaths()) > 0 {
-			Print(tr.Tr.Get("Ignoring global include / exclude paths to fulfil --all"))
+			printProgress(tr.Tr.Get("Ignoring global include / exclude paths to fulfil --all"))
 		}
 
 		if len(args) > 1 {
@@ -80,9 +140,9 @@ func fetchCommand(cmd *cobra.Command, args []string) {
 			for _, ref := range refs {
 				refShas = append(refShas, ref.Sha)
 			}
-			success = fetchRefs(refShas)
+			success = fetchRefs(refShas, watcher)
 		} else {
-			success = fetchAll()
+			success = fetchAll(watcher)
 		}
 
 	} else { // !all
@@ -90,13 +150,13 @@ func fetchCommand(cmd *cobra.Command, args []string) {
 
 		// Fetch refs sequentially per arg order; duplicates in later refs will be ignored
 		for _, ref := range refs {
-			Print("fetch: %s", tr.Tr.Get("Fetching reference %s", ref.Refspec()))
-			s := fetchRef(ref.Sha, filter)
+			printProgress(tr.Tr.Get("Fetching reference %s", ref.Refspec()))
+			s := fetchRef(ref.Sha, filter, watcher)
 			success = success && s
 		}
 
 		if fetchRecentArg || fetchPruneCfg.FetchRecentAlways {
-			s := fetchRecent(fetchPruneCfg, refs, filter)
+			s := fetchRecent(fetchPruneCfg, refs, filter, watcher)
 			success = success && s
 		}
 	}
@@ -106,7 +166,7 @@ func fetchCommand(cmd *cobra.Command, args []string) {
 		verifyUnreachable := fetchPruneCfg.PruneVerifyUnreachableAlways
 
 		// assume false for non available options in fetch
-		prune(fetchPruneCfg, verify, verifyUnreachable, false, false, false)
+		prune(fetchPruneCfg, verify, verifyUnreachable, false, fetchDryRunArg, fetchDryRunArg)
 	}
 
 	if !success {
@@ -114,6 +174,9 @@ func fetchCommand(cmd *cobra.Command, args []string) {
 		e := c.Endpoints.Endpoint("download", cfg.Remote())
 		Exit(tr.Tr.Get("error: failed to fetch some objects from '%s'", e.Url))
 	}
+	if fetchJsonArg {
+		watcher.dumpJson()
+	}
 }
 
 func pointersToFetchForRef(ref string, filter *filepathfilter.Filter) ([]*lfs.WrappedPointer, error) {
@@ -121,11 +184,7 @@ func pointersToFetchForRef(ref string, filter *filepathfilter.Filter) ([]*lfs.Wr
 	var multiErr error
 	tempgitscanner := lfs.NewGitScanner(cfg, func(p *lfs.WrappedPointer, err error) {
 		if err != nil {
-			if multiErr != nil {
-				multiErr = fmt.Errorf("%v\n%v", multiErr, err)
-			} else {
-				multiErr = err
-			}
+			multiErr = errors.Join(multiErr, err)
 			return
 		}
 
@@ -142,12 +201,12 @@ func pointersToFetchForRef(ref string, filter *filepathfilter.Filter) ([]*lfs.Wr
 }
 
 // Fetch all binaries for a given ref (that we don't have already)
-func fetchRef(ref string, filter *filepathfilter.Filter) bool {
+func fetchRef(ref string, filter *filepathfilter.Filter, watcher *fetchWatcher) bool {
 	pointers, err := pointersToFetchForRef(ref, filter)
 	if err != nil {
 		Panic(err, tr.Tr.Get("Could not scan for Git LFS files"))
 	}
-	return fetchAndReportToChan(pointers, filter, nil)
+	return fetch(pointers, watcher)
 }
 
 func pointersToFetchForRefs(refs []string) ([]*lfs.WrappedPointer, error) {
@@ -164,16 +223,12 @@ func pointersToFetchForRefs(refs []string) ([]*lfs.WrappedPointer, error) {
 	var numObjs int64
 	tempgitscanner := lfs.NewGitScanner(cfg, func(p *lfs.WrappedPointer, err error) {
 		if err != nil {
-			if multiErr != nil {
-				multiErr = fmt.Errorf("%v\n%v", multiErr, err)
-			} else {
-				multiErr = err
-			}
+			multiErr = errors.Join(multiErr, err)
 			return
 		}
 
 		numObjs++
-		task.Logf("fetch: %s", tr.Tr.GetN("%d object found", "%d objects found", int(numObjs), numObjs))
+		task.Log(tr.Tr.GetN("%d object found", "%d objects found", int(numObjs), numObjs))
 		pointers = append(pointers, p)
 	})
 
@@ -184,17 +239,17 @@ func pointersToFetchForRefs(refs []string) ([]*lfs.WrappedPointer, error) {
 	return pointers, multiErr
 }
 
-func fetchRefs(refs []string) bool {
+func fetchRefs(refs []string, watcher *fetchWatcher) bool {
 	pointers, err := pointersToFetchForRefs(refs)
 	if err != nil {
 		Panic(err, tr.Tr.Get("Could not scan for Git LFS files"))
 	}
-	return fetchAndReportToChan(pointers, nil, nil)
+	return fetch(pointers, watcher)
 }
 
 // Fetch all previous versions of objects from since to ref (not including final state at ref)
 // So this will fetch all the '-' sides of the diff from since to ref
-func fetchPreviousVersions(ref string, since time.Time, filter *filepathfilter.Filter) bool {
+func fetchPreviousVersions(ref string, since time.Time, filter *filepathfilter.Filter, watcher *fetchWatcher) bool {
 	var pointers []*lfs.WrappedPointer
 
 	tempgitscanner := lfs.NewGitScanner(cfg, func(p *lfs.WrappedPointer, err error) {
@@ -212,11 +267,11 @@ func fetchPreviousVersions(ref string, since time.Time, filter *filepathfilter.F
 		ExitWithError(err)
 	}
 
-	return fetchAndReportToChan(pointers, filter, nil)
+	return fetch(pointers, watcher)
 }
 
 // Fetch recent objects based on config
-func fetchRecent(fetchconf lfs.FetchPruneConfig, alreadyFetchedRefs []*git.Ref, filter *filepathfilter.Filter) bool {
+func fetchRecent(fetchconf lfs.FetchPruneConfig, alreadyFetchedRefs []*git.Ref, filter *filepathfilter.Filter, watcher *fetchWatcher) bool {
 	if fetchconf.FetchRecentRefsDays == 0 && fetchconf.FetchRecentCommitsDays == 0 {
 		return true
 	}
@@ -229,7 +284,7 @@ func fetchRecent(fetchconf lfs.FetchPruneConfig, alreadyFetchedRefs []*git.Ref,
 	}
 	// First find any other recent refs
 	if fetchconf.FetchRecentRefsDays > 0 {
-		Print("fetch: %s", tr.Tr.GetN(
+		printProgress(tr.Tr.GetN(
 			"Fetching recent branches within %v day",
 			"Fetching recent branches within %v days",
 			fetchconf.FetchRecentRefsDays,
@@ -248,8 +303,8 @@ func fetchRecent(fetchconf lfs.FetchPruneConfig, alreadyFetchedRefs []*git.Ref,
 				}
 			} else {
 				uniqueRefShas[ref.Sha] = ref.Name
-				Print("fetch: %s", tr.Tr.Get("Fetching reference %s", ref.Name))
-				k := fetchRef(ref.Sha, filter)
+				printProgress(tr.Tr.Get("Fetching reference %s", ref.Name))
+				k := fetchRef(ref.Sha, filter, watcher)
 				ok = ok && k
 			}
 		}
@@ -263,7 +318,7 @@ func fetchRecent(fetchconf lfs.FetchPruneConfig, alreadyFetchedRefs []*git.Ref,
 				Error(tr.Tr.Get("Couldn't scan commits at %v: %v", refName, err))
 				continue
 			}
-			Print("fetch: %s", tr.Tr.GetN(
+			printProgress(tr.Tr.GetN(
 				"Fetching changes within %v day of %v",
 				"Fetching changes within %v days of %v",
 				fetchconf.FetchRecentCommitsDays,
@@ -271,7 +326,7 @@ func fetchRecent(fetchconf lfs.FetchPruneConfig, alreadyFetchedRefs []*git.Ref,
 				refName,
 			))
 			commitsSince := summ.CommitDate.AddDate(0, 0, -fetchconf.FetchRecentCommitsDays)
-			k := fetchPreviousVersions(commit, commitsSince, filter)
+			k := fetchPreviousVersions(commit, commitsSince, filter, watcher)
 			ok = ok && k
 		}
 
@@ -279,10 +334,10 @@ func fetchRecent(fetchconf lfs.FetchPruneConfig, alreadyFetchedRefs []*git.Ref,
 	return ok
 }
 
-func fetchAll() bool {
+func fetchAll(watcher *fetchWatcher) bool {
 	pointers := scanAll()
-	Print("fetch: %s", tr.Tr.Get("Fetching all references..."))
-	return fetchAndReportToChan(pointers, nil, nil)
+	printProgress(tr.Tr.Get("Fetching all references..."))
+	return fetch(pointers, watcher)
 }
 
 func scanAll() []*lfs.WrappedPointer {
@@ -299,16 +354,12 @@ func scanAll() []*lfs.WrappedPointer {
 	var numObjs int64
 	tempgitscanner := lfs.NewGitScanner(cfg, func(p *lfs.WrappedPointer, err error) {
 		if err != nil {
-			if multiErr != nil {
-				multiErr = fmt.Errorf("%v\n%v", multiErr, err)
-			} else {
-				multiErr = err
-			}
+			multiErr = errors.Join(multiErr, err)
 			return
 		}
 
 		numObjs++
-		task.Logf("fetch: %s", tr.Tr.GetN("%d object found", "%d objects found", int(numObjs), numObjs))
+		task.Log(tr.Tr.GetN("%d object found", "%d objects found", int(numObjs), numObjs))
 		pointers = append(pointers, p)
 	})
 
@@ -323,47 +374,28 @@ func scanAll() []*lfs.WrappedPointer {
 	return pointers
 }
 
-// Fetch and report completion of each OID to a channel (optional, pass nil to skip)
+// Fetch
 // Returns true if all completed with no errors, false if errors were written to stderr/log
-func fetchAndReportToChan(allpointers []*lfs.WrappedPointer, filter *filepathfilter.Filter, out chan<- *lfs.WrappedPointer) bool {
-	ready, pointers, meter := readyAndMissingPointers(allpointers, filter)
+func fetch(allPointers []*lfs.WrappedPointer, watcher *fetchWatcher) bool {
+	pointersToFetch, meter := pointersToFetch(allPointers, watcher)
 	q := newDownloadQueue(
 		getTransferManifestOperationRemote("download", cfg.Remote()),
-		cfg.Remote(), tq.WithProgress(meter),
+		cfg.Remote(), tq.WithProgress(meter), tq.DryRun(fetchDryRunArg),
 	)
+	var wg sync.WaitGroup
 
-	if out != nil {
-		// If we already have it, or it won't be fetched
-		// report it to chan immediately to support pull/checkout
-		for _, p := range ready {
-			out <- p
-		}
-
-		dlwatch := q.Watch()
-
+	if watcher != nil {
+		transfers := q.Watch()
+		wg.Add(1)
 		go func() {
-			// fetch only reports single OID, but OID *might* be referenced by multiple
-			// WrappedPointers if same content is at multiple paths, so map oid->slice
-			oidToPointers := make(map[string][]*lfs.WrappedPointer, len(pointers))
-			for _, pointer := range pointers {
-				plist := oidToPointers[pointer.Oid]
-				oidToPointers[pointer.Oid] = append(plist, pointer)
+			defer wg.Done()
+			for t := range transfers {
+				watcher.registerTransfer(t)
 			}
-
-			for t := range dlwatch {
-				plist, ok := oidToPointers[t.Oid]
-				if !ok {
-					continue
-				}
-				for _, p := range plist {
-					out <- p
-				}
-			}
-			close(out)
 		}()
 	}
 
-	for _, p := range pointers {
+	for _, p := range pointersToFetch {
 		tracerx.Printf("fetch %v [%v]", p.Name, p.Oid)
 
 		q.Add(downloadTransfer(p))
@@ -378,40 +410,44 @@ func fetchAndReportToChan(allpointers []*lfs.WrappedPointer, filter *filepathfil
 		ok = false
 		FullError(err)
 	}
+	if watcher != nil {
+		wg.Wait()
+	}
 	return ok
 }
 
-func readyAndMissingPointers(allpointers []*lfs.WrappedPointer, filter *filepathfilter.Filter) ([]*lfs.WrappedPointer, []*lfs.WrappedPointer, *tq.Meter) {
+func pointersToFetch(allPointers []*lfs.WrappedPointer, watcher *fetchWatcher) ([]*lfs.WrappedPointer, *tq.Meter) {
 	logger := tasklog.NewLogger(os.Stdout,
 		tasklog.ForceProgress(cfg.ForceProgress()),
 	)
-	meter := buildProgressMeter(false, tq.Download)
+	meter := buildProgressMeter(hasToPrintTransfers(), tq.Download)
 	logger.Enqueue(meter)
 
-	seen := make(map[string]bool, len(allpointers))
-	missing := make([]*lfs.WrappedPointer, 0, len(allpointers))
-	ready := make([]*lfs.WrappedPointer, 0, len(allpointers))
+	pointersToFetch := make([]*lfs.WrappedPointer, 0, len(allPointers))
 
-	for _, p := range allpointers {
-		// no need to download the same object multiple times
-		if seen[p.Oid] {
+	for _, p := range allPointers {
+		// if running with --dry-run or --refetch, skip objects that have already been virtually or
+		// already forcefully fetched
+		if watcher != nil && watcher.hasObserved(p.Oid) {
 			continue
 		}
 
-		seen[p.Oid] = true
+		// empty files are special, we always skip them in upload/download operations
+		if p.Size == 0 {
+			continue
+		}
 
-		// no need to download objects that exist locally already
+		// no need to download objects that exist locally already, unless `--refetch` was provided
 		lfs.LinkOrCopyFromReference(cfg, p.Oid, p.Size)
-		if cfg.LFSObjectExists(p.Oid, p.Size) {
-			ready = append(ready, p)
+		if !fetchRefetchArg && cfg.LFSObjectExists(p.Oid, p.Size) {
 			continue
 		}
 
-		missing = append(missing, p)
+		pointersToFetch = append(pointersToFetch, p)
 		meter.Add(p.Size)
 	}
 
-	return ready, missing, meter
+	return pointersToFetch, meter
 }
 
 func init() {
@@ -421,5 +457,8 @@ func init() {
 		cmd.Flags().BoolVarP(&fetchRecentArg, "recent", "r", false, "Fetch recent refs & commits")
 		cmd.Flags().BoolVarP(&fetchAllArg, "all", "a", false, "Fetch all LFS files ever referenced")
 		cmd.Flags().BoolVarP(&fetchPruneArg, "prune", "p", false, "After fetching, prune old data")
+		cmd.Flags().BoolVar(&fetchRefetchArg, "refetch", false, "Also fetch objects that are already present locally")
+		cmd.Flags().BoolVarP(&fetchDryRunArg, "dry-run", "d", false, "Do not fetch, only show what would be fetched")
+		cmd.Flags().BoolVarP(&fetchJsonArg, "json", "j", false, "Give the output in a stable JSON format for scripts")
 	})
 }
