@@ -1,5 +1,3 @@
-//go:generate goversioninfo
-
 package main
 
 import (
@@ -9,7 +7,8 @@ import (
 	"sync"
 	"syscall"
 
-	"github.com/git-lfs/git-lfs/commands"
+	"github.com/git-lfs/git-lfs/v3/commands"
+	"github.com/git-lfs/git-lfs/v3/tr"
 )
 
 func main() {
@@ -22,7 +21,7 @@ func main() {
 		for {
 			sig := <-c
 			once.Do(commands.Cleanup)
-			fmt.Fprintf(os.Stderr, "\nExiting because of %q signal.\n", sig)
+			fmt.Fprintf(os.Stderr, "\n%s\n", tr.Tr.Get("Exiting because of %q signal.", sig))
 
 			exitCode := 1
 			if sysSig, ok := sig.(syscall.Signal); ok {
