@@ -1,27 +1,26 @@
 package git
 
 import (
-	"bufio"
-	"bytes"
-	"fmt"
+	"encoding/hex"
 	"io"
-	"io/ioutil"
-	"strconv"
 
-	"github.com/git-lfs/git-lfs/errors"
-	"github.com/rubyist/tracerx"
+	"github.com/git-lfs/git-lfs/v3/tr"
+	"github.com/git-lfs/gitobj/v2"
+	"github.com/git-lfs/gitobj/v2/errors"
 )
 
 // object represents a generic Git object of any type.
 type object struct {
 	// Contents reads Git's internal object representation.
-	Contents *io.LimitedReader
+	Contents io.Reader
 	// Oid is the ID of the object.
 	Oid string
 	// Size is the size in bytes of the object.
 	Size int64
 	// Type is the type of the object being held.
 	Type string
+	// object is the gitobj object being handled.
+	object gitobj.Object
 }
 
 // ObjectScanner is a scanner type that scans for Git objects reference-able in
@@ -33,74 +32,34 @@ type ObjectScanner struct {
 	// its last scan, or nil.
 	err error
 
-	// from is the buffered source of input to the *ObjectScanner. It
-	// expects input in the form described by
-	// https://git-scm.com/docs/git-cat-file.
-	from *bufio.Reader
-	// to is a writer which accepts the object's OID to be scanned.
-	to io.Writer
-	// closeFn is an optional function that is run before the ObjectScanner
-	// is closed. It is designated to clean up and close any resources held
-	// by the ObjectScanner during runtime.
-	closeFn func() error
+	gitobj *gitobj.ObjectDatabase
 }
 
 // NewObjectScanner constructs a new instance of the `*ObjectScanner` type and
-// returns it. It backs the ObjectScanner with an invocation of the `git
-// cat-file --batch` command. If any errors were encountered while starting that
-// command, they will be returned immediately.
-//
+// returns it. It backs the ObjectScanner with an ObjectDatabase from the
+// github.com/git-lfs/gitobj/v2 package.
+// If any errors are encountered while creating the ObjectDatabase,
+// they will be returned immediately.
 // Otherwise, an `*ObjectScanner` is returned with no error.
-func NewObjectScanner() (*ObjectScanner, error) {
-	cmd := gitNoLFS("cat-file", "--batch")
-	stdout, err := cmd.StdoutPipe()
+func NewObjectScanner(gitEnv, osEnv Environment) (*ObjectScanner, error) {
+	gitdir, err := GitCommonDir()
 	if err != nil {
-		return nil, errors.Wrap(err, "open stdout")
-	}
-	stdin, err := cmd.StdinPipe()
-	if err != nil {
-		return nil, errors.Wrap(err, "open stdin")
-	}
-
-	stderr, err := cmd.StderrPipe()
-	if err != nil {
-		return nil, errors.Wrap(err, "open stderr")
-	}
-
-	closeFn := func() error {
-		if err := stdin.Close(); err != nil {
-			return err
-		}
-
-		msg, _ := ioutil.ReadAll(stderr)
-		if err = cmd.Wait(); err != nil {
-			return errors.Errorf("Error in git cat-file --batch: %v %v", err, string(msg))
-		}
-
-		return nil
-	}
-
-	tracerx.Printf("run_command: git cat-file --batch")
-	if err := cmd.Start(); err != nil {
 		return nil, err
 	}
 
-	return &ObjectScanner{
-		from: bufio.NewReaderSize(stdout, 16384),
-		to:   stdin,
+	gitobj, err := ObjectDatabase(osEnv, gitEnv, gitdir, "")
+	if err != nil {
+		return nil, err
+	}
 
-		closeFn: closeFn,
-	}, nil
+	return NewObjectScannerFrom(gitobj), nil
 }
 
 // NewObjectScannerFrom returns a new `*ObjectScanner` populated with data from
 // the given `io.Reader`, "r". It supplies no close function, and discards any
 // input given to the Scan() function.
-func NewObjectScannerFrom(r io.Reader) *ObjectScanner {
-	return &ObjectScanner{
-		from: bufio.NewReader(r),
-		to:   ioutil.Discard,
-	}
+func NewObjectScannerFrom(db *gitobj.ObjectDatabase) *ObjectScanner {
+	return &ObjectScanner{gitobj: db}
 }
 
 // Scan scans for a particular object given by the "oid" parameter. Once the
@@ -135,9 +94,9 @@ func (s *ObjectScanner) Close() error {
 		return nil
 	}
 
-	if s.closeFn != nil {
-		return s.closeFn()
-	}
+	s.reset()
+	s.gitobj.Close()
+
 	return nil
 }
 
@@ -166,26 +125,18 @@ func (s *ObjectScanner) Type() string {
 // operation.
 func (s *ObjectScanner) Err() error { return s.err }
 
-// reset resets the `*ObjectScanner` to scan again by advancing the reader (if
-// necessary) and clearing both the object and error fields on the
-// `*ObjectScanner` instance.
 func (s *ObjectScanner) reset() error {
 	if s.object != nil {
-		if s.object.Contents != nil {
-			remaining := s.object.Contents.N
-			if _, err := io.CopyN(ioutil.Discard, s.object.Contents, remaining); err != nil {
-				return errors.Wrap(err, "unwind contents")
+		if c, ok := s.object.object.(interface {
+			Close() error
+		}); ok && c != nil {
+			if err := c.Close(); err != nil {
+				return err
 			}
 		}
-
-		// Consume extra LF inserted by cat-file
-		if _, err := s.from.ReadByte(); err != nil {
-			return err
-		}
 	}
 
 	s.object, s.err = nil, nil
-
 	return nil
 }
 
@@ -194,7 +145,7 @@ type missingErr struct {
 }
 
 func (m *missingErr) Error() string {
-	return fmt.Sprintf("missing object: %s", m.oid)
+	return tr.Tr.Get("missing object: %s", m.oid)
 }
 
 func IsMissingObject(err error) bool {
@@ -202,36 +153,39 @@ func IsMissingObject(err error) bool {
 	return ok
 }
 
-// scan scans for and populates a new Git object given an OID.
+func mustDecode(oid string) []byte {
+	x, _ := hex.DecodeString(oid)
+	return x
+}
+
 func (s *ObjectScanner) scan(oid string) (*object, error) {
-	if _, err := fmt.Fprintln(s.to, oid); err != nil {
-		return nil, err
-	}
+	var (
+		obj      gitobj.Object
+		size     int64
+		contents io.Reader
+	)
 
-	l, err := s.from.ReadBytes('\n')
+	obj, err := s.gitobj.Object(mustDecode(oid))
 	if err != nil {
-		return nil, err
-	}
-
-	fields := bytes.Fields(l)
-	switch len(fields) {
-	case 2:
-		if string(fields[1]) == "missing" {
+		if errors.IsNoSuchObject(err) {
 			return nil, &missingErr{oid: oid}
 		}
-		break
-	case 3:
-		oid = string(fields[0])
-		typ := string(fields[1])
-		size, _ := strconv.Atoi(string(fields[2]))
-		contents := io.LimitReader(s.from, int64(size))
-
-		return &object{
-			Contents: contents.(*io.LimitedReader),
-			Oid:      oid,
-			Size:     int64(size),
-			Type:     typ,
-		}, nil
+		return nil, err
 	}
-	return nil, errors.Errorf("invalid line: %q", l)
+
+	// Currently, we're only interested in the size and contents of blobs,
+	// and gitobj only exposes the size easily for us for blobs anyway.
+	if obj.Type() == gitobj.BlobObjectType {
+		blob := obj.(*gitobj.Blob)
+		size = blob.Size
+		contents = blob.Contents
+	}
+
+	return &object{
+		Contents: contents,
+		Oid:      oid,
+		Size:     size,
+		Type:     obj.Type().String(),
+		object:   obj,
+	}, nil
 }
