@@ -16,23 +16,17 @@ import (
 )
 
 func (f *GitFilter) SmudgeToFile(filename string, ptr *Pointer, download bool, manifest tq.Manifest, cb tools.CopyCallback) error {
-	tools.MkdirAll(filepath.Dir(filename), f.cfg)
-
-	if stat, _ := os.Stat(filename); stat != nil {
+	// When no pointer file exists on disk, we should use the permissions
+	// defined for the file in Git, since the executable mode may be set.
+	// However, to conform with our legacy behaviour, we do not do this
+	// at present.
+	var mode os.FileMode = 0666
+	if stat, _ := os.Lstat(filename); stat != nil && stat.Mode().IsRegular() {
 		if ptr.Size == 0 && stat.Size() == 0 {
 			return nil
 		}
 
-		if stat.Mode()&0200 == 0 {
-			if err := os.Chmod(filename, stat.Mode()|0200); err != nil {
-				return errors.Wrap(err,
-					tr.Tr.Get("Could not restore write permission"))
-			}
-
-			// When we're done, return the file back to its normal
-			// permission bits.
-			defer os.Chmod(filename, stat.Mode())
-		}
+		mode = stat.Mode().Perm()
 	}
 
 	abs, err := filepath.Abs(filename)
@@ -40,9 +34,13 @@ func (f *GitFilter) SmudgeToFile(filename string, ptr *Pointer, download bool, m
 		return errors.New(tr.Tr.Get("could not produce absolute path for %q", filename))
 	}
 
-	file, err := os.Create(abs)
+	if err := os.Remove(abs); err != nil && !os.IsNotExist(err) {
+		return errors.Wrap(err, tr.Tr.Get("could not remove working directory file %q", filename))
+	}
+
+	file, err := os.OpenFile(abs, os.O_WRONLY|os.O_CREATE|os.O_EXCL, mode)
 	if err != nil {
-		return errors.New(tr.Tr.Get("could not create working directory file: %v", err))
+		return errors.Wrap(err, tr.Tr.Get("could not create working directory file %q", filename))
 	}
 	defer file.Close()
 	if _, err := f.Smudge(file, ptr, filename, download, manifest, cb); err != nil {
