@@ -5,8 +5,8 @@ import (
 	"bytes"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"regexp"
+	"strconv"
 	"strings"
 	"time"
 
@@ -70,7 +70,7 @@ func scanUnpushed(cb GitScannerFoundPointer, remote string) error {
 	return nil
 }
 
-func scanStashed(cb GitScannerFoundPointer, s *GitScanner) error {
+func scanStashed(cb GitScannerFoundPointer) error {
 	// Stashes are actually 2-3 commits, each containing one of:
 	// 1. Working copy (WIP) modified files
 	// 2. Index changes
@@ -137,6 +137,14 @@ func scanStashed(cb GitScannerFoundPointer, s *GitScanner) error {
 func parseScannerLogOutput(cb GitScannerFoundPointer, direction LogDiffDirection, cmd *subprocess.BufferedCmd, filter *filepathfilter.Filter) {
 	ch := make(chan gitscannerResult, chanBufSize)
 
+	cherr := make(chan []byte)
+
+	go func() {
+		stderr, _ := io.ReadAll(cmd.Stderr)
+		cherr <- stderr
+		close(cherr)
+	}()
+
 	go func() {
 		scanner := newLogScanner(direction, cmd.Stdout)
 		scanner.Filter = filter
@@ -146,10 +154,10 @@ func parseScannerLogOutput(cb GitScannerFoundPointer, direction LogDiffDirection
 			}
 		}
 		if err := scanner.Err(); err != nil {
-			ioutil.ReadAll(cmd.Stdout)
+			io.ReadAll(cmd.Stdout)
 			ch <- gitscannerResult{Err: errors.New(tr.Tr.Get("error while scanning `git log`: %v", err))}
 		}
-		stderr, _ := ioutil.ReadAll(cmd.Stderr)
+		stderr := <-cherr
 		err := cmd.Wait()
 		if err != nil {
 			ch <- gitscannerResult{Err: errors.New(tr.Tr.Get("error in `git log`: %v %v", err, string(stderr)))}
@@ -217,7 +225,7 @@ func newLogScanner(dir LogDiffDirection, r io.Reader) *logScanner {
 		// no need to compile these regexes on every `git-lfs` call, just ones that
 		// use the scanner.
 		commitHeaderRegex:    regexp.MustCompile(fmt.Sprintf(`^lfs-commit-sha: (%s)(?: (%s))*`, git.ObjectIDRegex, git.ObjectIDRegex)),
-		fileHeaderRegex:      regexp.MustCompile(`^diff --git a\/(.+?)\s+b\/(.+)`),
+		fileHeaderRegex:      regexp.MustCompile(`^diff --git "?a\/(.+?)\s+"?b\/(.+)`),
 		fileMergeHeaderRegex: regexp.MustCompile(`^diff --cc (.+)`),
 		pointerDataRegex:     regexp.MustCompile(`^([\+\- ])(version https://git-lfs|oid sha256|size|ext-).*$`),
 	}
@@ -342,6 +350,17 @@ func (s *logScanner) scan() (*WrappedPointer, bool) {
 }
 
 func (s *logScanner) setFilename(name string) {
+	// Trim last character if it's a quote
+	if len(name) > 0 && name[len(name)-1] == '"' {
+		name = name[:len(name)-1]
+	}
+
+	// Convert octals to proper UTF-8 code
+	unquotedName, err := strconv.Unquote(`"` + name + `"`)
+	if err == nil {
+		name = unquotedName
+	}
+
 	s.currentFilename = name
 	s.currentFileIncluded = s.Filter.Allows(name)
 }
