@@ -16,14 +16,16 @@ import (
 )
 
 var (
-	defaultEndpointFinder = NewEndpointFinder(nil)
+	defaultEndpointFinder  = NewEndpointFinder(nil)
+	defaultMaxAuthAttempts = 3
 )
 
 // DoWithAuth sends an HTTP request to get an HTTP response. It attempts to add
 // authentication from netrc or git's credential helpers if necessary,
 // supporting basic authentication.
 func (c *Client) DoWithAuth(remote string, access creds.Access, req *http.Request) (*http.Response, error) {
-	res, err := c.doWithAuth(remote, access, req, nil)
+	count := 0
+	res, err := c.doWithAuth(remote, &count, access, req, nil)
 
 	if errors.IsAuthError(err) {
 		if len(req.Header.Get("Authorization")) == 0 {
@@ -44,7 +46,8 @@ func (c *Client) DoWithAuth(remote string, access creds.Access, req *http.Reques
 // the same way as DoWithAuth, but will not retry the request if it fails with
 // an authorization error.
 func (c *Client) DoWithAuthNoRetry(remote string, access creds.Access, req *http.Request) (*http.Response, error) {
-	return c.doWithAuth(remote, access, req, nil)
+	count := 0
+	return c.doWithAuth(remote, &count, access, req, nil)
 }
 
 // DoAPIRequestWithAuth sends an HTTP request to get an HTTP response similarly
@@ -57,18 +60,24 @@ func (c *Client) DoAPIRequestWithAuth(remote string, req *http.Request) (*http.R
 	return c.DoWithAuth(remote, access, req)
 }
 
-func (c *Client) doWithAuth(remote string, access creds.Access, req *http.Request, via []*http.Request) (*http.Response, error) {
+func (c *Client) doWithAuth(remote string, count *int, access creds.Access, req *http.Request, via []*http.Request) (*http.Response, error) {
+	if *count == defaultMaxAuthAttempts {
+		return nil, fmt.Errorf("too many authentication attempts")
+	}
+
 	req.Header = c.client.ExtraHeadersFor(req)
 
 	credWrapper, err := c.getCreds(remote, access, req)
 	if err != nil {
 		return nil, err
 	}
+	c.credContext.SetStateFields(credWrapper.Creds["state[]"])
 
-	res, err := c.doWithCreds(req, credWrapper, access, via)
+	res, err := c.doWithCreds(req, count, credWrapper, access, via)
 	if err != nil {
 		if errors.IsAuthError(err) {
-			newMode, newModes := getAuthAccess(res, access.Mode(), c.access)
+			multistage := credWrapper.Creds.IsMultistage()
+			newMode, newModes, headers := getAuthAccess(res, access.Mode(), c.access, multistage)
 			newAccess := access.Upgrade(newMode)
 			if newAccess.Mode() != access.Mode() {
 				c.Endpoints.SetAccess(newAccess)
@@ -77,8 +86,13 @@ func (c *Client) doWithAuth(remote string, access creds.Access, req *http.Reques
 
 			if credWrapper.Creds != nil {
 				req.Header.Del("Authorization")
-				credWrapper.CredentialHelper.Reject(credWrapper.Creds)
+				if multistage && *count < defaultMaxAuthAttempts && res != nil && res.StatusCode == 401 {
+					*count++
+				} else {
+					credWrapper.CredentialHelper.Reject(credWrapper.Creds)
+				}
 			}
+			c.credContext.SetWWWAuthHeaders(headers)
 		}
 	}
 
@@ -89,7 +103,7 @@ func (c *Client) doWithAuth(remote string, access creds.Access, req *http.Reques
 	return res, err
 }
 
-func (c *Client) doWithCreds(req *http.Request, credWrapper creds.CredentialHelperWrapper, access creds.Access, via []*http.Request) (*http.Response, error) {
+func (c *Client) doWithCreds(req *http.Request, count *int, credWrapper creds.CredentialHelperWrapper, access creds.Access, via []*http.Request) (*http.Response, error) {
 	if access.Mode() == creds.NegotiateAccess {
 		return c.doWithNegotiate(req, credWrapper)
 	}
@@ -110,7 +124,7 @@ func (c *Client) doWithCreds(req *http.Request, credWrapper creds.CredentialHelp
 		return res, errors.New(tr.Tr.Get("failed to redirect request"))
 	}
 
-	return c.doWithAuth("", access, redirectedReq, via)
+	return c.doWithAuth("", count, access, redirectedReq, via)
 }
 
 // getCreds fills the authorization header for the given request if possible,
@@ -161,7 +175,7 @@ func (c *Client) getCreds(remote string, access creds.Access, req *http.Request)
 		err = credWrapper.FillCreds()
 		if err == nil {
 			tracerx.Printf("Filled credentials for %s", credsURL)
-			setRequestAuth(req, credWrapper.Creds["username"], credWrapper.Creds["password"])
+			setRequestAuthWithCreds(req, credWrapper.Creds)
 		}
 		return credWrapper, err
 	}
@@ -302,6 +316,20 @@ func setRequestAuth(req *http.Request, user, pass string) {
 	req.Header.Set("Authorization", auth)
 }
 
+func setRequestAuthWithCreds(req *http.Request, c creds.Creds) {
+	authtype := creds.FirstEntryForKey(c, "authtype")
+	credential := creds.FirstEntryForKey(c, "credential")
+	if len(authtype) == 0 && len(credential) == 0 {
+		user := creds.FirstEntryForKey(c, "username")
+		pass := creds.FirstEntryForKey(c, "password")
+		setRequestAuth(req, user, pass)
+		return
+	}
+
+	auth := fmt.Sprintf("%s %s", authtype, credential)
+	req.Header.Set("Authorization", auth)
+}
+
 func getReqOperation(req *http.Request) string {
 	operation := "download"
 	if req.Method == "POST" || req.Method == "PUT" {
@@ -314,14 +342,18 @@ var (
 	authenticateHeaders = []string{"Lfs-Authenticate", "Www-Authenticate"}
 )
 
-func getAuthAccess(res *http.Response, access creds.AccessMode, modes []creds.AccessMode) (creds.AccessMode, []creds.AccessMode) {
+func getAuthAccess(res *http.Response, access creds.AccessMode, modes []creds.AccessMode, multistage bool) (creds.AccessMode, []creds.AccessMode, []string) {
 	newModes := make([]creds.AccessMode, 0, len(modes))
 	for _, mode := range modes {
-		if access != mode {
+		if multistage || access != mode {
 			newModes = append(newModes, mode)
 		}
 	}
+	headers := make([]string, 0)
 	if res != nil {
+		for _, headerName := range authenticateHeaders {
+			headers = append(headers, res.Header[headerName]...)
+		}
 		supportedModes := make(map[creds.AccessMode]struct{})
 		for _, headerName := range authenticateHeaders {
 			for _, auth := range res.Header[headerName] {
@@ -330,18 +362,15 @@ func getAuthAccess(res *http.Response, access creds.AccessMode, modes []creds.Ac
 					continue
 				}
 
-				switch creds.AccessMode(pieces[0]) {
-				case creds.BasicAccess, creds.NegotiateAccess:
-					supportedModes[creds.AccessMode(pieces[0])] = struct{}{}
-				}
+				supportedModes[creds.AccessMode(pieces[0])] = struct{}{}
 			}
 		}
 		for _, mode := range newModes {
 			if _, ok := supportedModes[mode]; ok {
-				return mode, newModes
+				return mode, newModes, headers
 			}
 		}
 	}
 
-	return creds.BasicAccess, newModes
+	return creds.BasicAccess, newModes, headers
 }
