@@ -6,16 +6,18 @@ envInitConfig='git config filter.lfs.process = "git-lfs filter-process"
 git config filter.lfs.smudge = "git-lfs smudge -- %f"
 git config filter.lfs.clean = "git-lfs clean -- %f"'
 
-unset_vars() {
-    # If set, these will cause the test to fail.
-    unset GIT_LFS_NO_TEST_COUNT GIT_LFS_LOCK_ACQUIRE_DISABLED
-}
+if [ "$IS_WINDOWS" -eq 1 ]; then
+  export MSYS2_ENV_CONV_EXCL="GIT_LFS_TEST_DIR"
+fi
+
+# The "git lfs env" command should ignore this environment variable
+# despite the "GIT_" strings in its name and value.
+export TEST_GIT_EXAMPLE="GIT_EXAMPLE"
 
 begin_test "env with no remote"
 (
   set -e
   reponame="env-no-remote"
-  unset_vars
   mkdir $reponame
   cd $reponame
   git init
@@ -67,7 +69,6 @@ begin_test "env with origin remote"
 (
   set -e
   reponame="env-origin-remote"
-  unset_vars
   mkdir $reponame
   cd $reponame
   git init
@@ -125,7 +126,6 @@ begin_test "env with multiple remotes"
 (
   set -e
   reponame="env-multiple-remotes"
-  unset_vars
   mkdir $reponame
   cd $reponame
   git init
@@ -186,7 +186,6 @@ begin_test "env with other remote"
 (
   set -e
   reponame="env-other-remote"
-  unset_vars
   mkdir $reponame
   cd $reponame
   git init
@@ -245,7 +244,6 @@ begin_test "env with multiple remotes and lfs.url config"
 (
   set -e
   reponame="env-multiple-remotes-with-lfs-url"
-  unset_vars
   mkdir $reponame
   cd $reponame
   git init
@@ -305,7 +303,6 @@ begin_test "env with multiple remotes and lfs configs"
 (
   set -e
   reponame="env-multiple-remotes-lfs-configs"
-  unset_vars
   mkdir $reponame
   cd $reponame
   git init
@@ -367,7 +364,6 @@ begin_test "env with multiple remotes and batch configs"
 (
   set -e
   reponame="env-multiple-remotes-lfs-batch-configs"
-  unset_vars
   mkdir $reponame
   cd $reponame
   git init
@@ -429,8 +425,6 @@ begin_test "env with .lfsconfig"
 (
   set -e
   reponame="env-with-lfsconfig"
-  unset_vars
-
   git init $reponame
   cd $reponame
 
@@ -499,7 +493,6 @@ begin_test "env with environment variables"
 (
   set -e
   reponame="env-with-envvars"
-  unset_vars
   git init $reponame
   mkdir -p $reponame/a/b/c
 
@@ -677,7 +670,6 @@ begin_test "env with bare repo"
 (
   set -e
   reponame="env-with-bare-repo"
-  unset_vars
   git init --bare $reponame
   cd $reponame
 
@@ -725,7 +717,6 @@ begin_test "env with multiple ssh remotes"
 (
   set -e
   reponame="env-with-ssh"
-  unset_vars
   mkdir $reponame
   cd $reponame
   git init
@@ -877,7 +868,6 @@ begin_test "env with extra transfer methods"
 (
   set -e
   reponame="env-with-transfers"
-  unset_vars
   git init $reponame
   cd $reponame
 
@@ -938,7 +928,6 @@ begin_test "env with multiple remotes and ref"
 (
   set -e
   reponame="env-multiple-remotes-ref"
-  unset_vars
   mkdir $reponame
   cd $reponame
   git init
@@ -1001,7 +990,6 @@ begin_test "env with unicode"
   # This contains a Unicode apostrophe, an E with grave accent, and a Euro sign.
   # Only the middle one is representable in ISO-8859-1.
   reponame="env-d’autre-nom-très-bizarr€"
-  unset_vars
   mkdir $reponame
   cd $reponame
   git init
@@ -1063,7 +1051,6 @@ end_test
 begin_test "env outside a repository"
 (
   set -e
-  unset_vars
 
   # This may or may not work, depending on the system, but it should at least
   # potentially cause Git to print non-English messages.
@@ -1113,7 +1100,6 @@ begin_test "env with duplicate endpoints"
 (
   set -e
   reponame="env-duplicate-endpoints"
-  unset_vars
   mkdir $reponame
   cd $reponame
   git init
