@@ -20,12 +20,12 @@ for typ in "${expiration_types[@]}"; do
     git add .gitattributes
     git commit -m "initial commit"
 
-    printf "$contents" > a.dat
+    printf "%s" "$contents" > a.dat
 
     git add a.dat
     git commit -m "add a.dat"
 
-    GIT_TRACE=1 git push origin master 2>&1 | tee push.log
+    GIT_TRACE=1 git push origin main 2>&1 | tee push.log
     if [ "0" -eq "${PIPESTATUS[0]}" ]; then
       echo >&2 "fatal: expected push to fail, didn't"
       exit 1
@@ -37,7 +37,7 @@ for typ in "${expiration_types[@]}"; do
 done
 
 for typ in "${expiration_types[@]}"; do
-  begin_test "ssh expired ($typ time)"
+  begin_test "ssh expired ($typ time; git-lfs-authenticate)"
   (
     set -e
 
@@ -55,12 +55,12 @@ for typ in "${expiration_types[@]}"; do
     git add .gitattributes
     git commit -m "initial commit"
 
-    printf "$contents" > a.dat
+    printf "%s" "$contents" > a.dat
 
     git add a.dat
     git commit -m "add a.dat"
 
-    GIT_TRACE=1 git push origin master 2>&1 | tee push.log
+    GIT_TRACE=1 git push origin main 2>&1 | tee push.log
     grep "ssh cache expired" push.log
   )
   end_test
