@@ -142,6 +142,31 @@ begin_test "migrate import (given branch with filter)"
 )
 end_test
 
+begin_test "migrate import (.git objects/symlink)"
+(
+  set -e
+  mkdir other
+
+  setup_multiple_local_branches
+
+  mv .git/objects ../other/
+  ln -s ../../other/objects .git/objects
+
+  md_oid="$(calc_oid "$(git cat-file -p :a.md)")"
+  txt_oid="$(calc_oid "$(git cat-file -p :a.txt)")"
+  md_feature_oid="$(calc_oid "$(git cat-file -p my-feature:a.md)")"
+
+  git lfs migrate import
+
+  assert_pointer "refs/heads/main" "a.md" "$md_oid" "140"
+  assert_pointer "refs/heads/main" "a.txt" "$txt_oid" "120"
+
+  assert_local_object "$md_oid" "140"
+  assert_local_object "$txt_oid" "120"
+  refute_local_object "$md_feature_oid" "30"
+)
+end_test
+
 begin_test "migrate import (default branch, exclude remote refs)"
 (
   set -e
@@ -629,7 +654,7 @@ begin_test "migrate import (existing .gitattributes symlink)"
     exit 1
   fi
 
-  grep "migrate: expected '.gitattributes' to be a file, got a symbolic link" migrate.log
+  grep "expected '.gitattributes' to be a file, got a symbolic link" migrate.log
 
   main="$(git rev-parse refs/heads/main)"
 
@@ -823,7 +848,10 @@ begin_test "migrate import (--everything and --include with glob pattern)"
   md_feature_oid="$(calc_oid "$(git cat-file -p "refs/heads/my-feature:a.md")")"
   txt_feature_oid="$(calc_oid "$(git cat-file -p "refs/heads/my-feature:a.txt")")"
 
-  git lfs migrate import --verbose --everything --include='*.[mM][dD]'
+  original_head="$(git rev-parse HEAD)"
+
+  git lfs migrate import --verbose --everything --include='*.[mM][dD]' --yes 2>&1 | tee migrate.log
+  grep -q "  commit ${original_head}: a\.md" migrate.log
 
   assert_pointer "refs/heads/main" "a.md" "$md_main_oid" "140"
   assert_pointer "refs/heads/my-feature" "a.md" "$md_feature_oid" "30"
@@ -849,7 +877,10 @@ begin_test "migrate import (--everything with tag pointing to tag)"
   git tag -a -m abc abc refs/heads/main
   git tag -a -m def def refs/tags/abc
 
-  git lfs migrate import --verbose --everything --include='*.[mM][dD]'
+  original_head="$(git rev-parse HEAD)"
+
+  git lfs migrate import --verbose --everything --include='*.[mM][dD]' --yes 2>&1 | tee migrate.log
+  grep -q "  commit ${original_head}: a\.md" migrate.log
 
   assert_pointer "refs/heads/main" "a.md" "$md_main_oid" "140"
   assert_pointer "refs/tags/abc" "a.md" "$md_main_oid" "140"
@@ -909,7 +940,7 @@ begin_test "migrate import (handle copies of files)"
 )
 end_test
 
-begin_test "migrate import (filter matches files only)"
+begin_test "migrate import (filter matches files only) (path cache settings)"
 (
   set -e
 
@@ -926,6 +957,27 @@ begin_test "migrate import (filter matches files only)"
   assert_local_object "$txt_foo_oid" "120"
   assert_local_object "$txt_bar_oid" "120"
   refute_local_object "$md_bar_oid"
+
+  # Also test with various path filter cache settings.
+  for cache in "none" "1" "2" "unlimited" "not valid"; do
+    cd ..
+    rm -rf "$reponame"
+    setup_single_local_branch_same_file_tree_ext
+
+    txt_root_oid="$(calc_oid "$(git cat-file -p :a.txt)")"
+    txt_foo_oid="$(calc_oid "$(git cat-file -p :foo/a.txt)")"
+    md_bar_oid="$(calc_oid "$(git cat-file -p :bar.txt/b.md)")"
+    txt_bar_oid="$(calc_oid "$(git cat-file -p :bar.txt/b.txt)")"
+
+    git config "lfs.pathFilterCacheSize" "$cache"
+
+    git lfs migrate import --include="*.txt"
+
+    assert_local_object "$txt_root_oid" "120"
+    assert_local_object "$txt_foo_oid" "120"
+    assert_local_object "$txt_bar_oid" "120"
+    refute_local_object "$md_bar_oid"
+  done
 )
 end_test
 
@@ -1030,7 +1082,7 @@ begin_test "migrate import (dirty copy, default negative answer)"
   original_main="$(git rev-parse main)"
 
   echo | git lfs migrate import --everything 2>&1 | tee migrate.log
-  grep "migrate: working copy must not be dirty" migrate.log
+  grep "working copy must not be dirty" migrate.log
 
   migrated_main="$(git rev-parse main)"
 
@@ -1047,7 +1099,7 @@ begin_test "migrate import (dirty copy, negative answer)"
   original_main="$(git rev-parse main)"
 
   echo "n" | git lfs migrate import --everything 2>&1 | tee migrate.log
-  grep "migrate: working copy must not be dirty" migrate.log
+  grep "working copy must not be dirty" migrate.log
 
   migrated_main="$(git rev-parse main)"
 
@@ -1069,7 +1121,7 @@ begin_test "migrate import (dirty copy, unknown then negative answer)"
 
   [ "2" -eq "$(grep -o "override changes in your working copy" migrate.log \
     | wc -l | awk '{ print $1 }')" ]
-  grep "migrate: working copy must not be dirty" migrate.log
+  grep "working copy must not be dirty" migrate.log
 
   migrated_main="$(git rev-parse main)"
 
@@ -1086,7 +1138,7 @@ begin_test "migrate import (dirty copy, positive answer)"
   oid="$(calc_oid "$(git cat-file -p :a.txt)")"
 
   echo "y" | git lfs migrate import --everything 2>&1 | tee migrate.log
-  grep "migrate: changes in your working copy will be overridden ..." \
+  grep "changes in your working copy will be overridden ..." \
     migrate.log
 
   assert_pointer "refs/heads/main" "a.txt" "$oid" "5"
