@@ -5,9 +5,11 @@ import (
 	"math"
 	"strconv"
 	"strings"
+	"time"
 	"unicode"
 
-	"github.com/git-lfs/git-lfs/errors"
+	"github.com/git-lfs/git-lfs/v3/errors"
+	"github.com/git-lfs/git-lfs/v3/tr"
 )
 
 const (
@@ -23,6 +25,10 @@ const (
 	Gigabyte = 1000 * Megabyte
 	Terabyte = 1000 * Gigabyte
 	Petabyte = 1000 * Terabyte
+
+	// eps is the machine epsilon, or a 64-bit floating point value
+	// reasonably close to zero.
+	eps float64 = 7.0/3 - 4.0/3 - 1.0
 )
 
 var bytesTable = map[string]uint64{
@@ -72,7 +78,7 @@ func ParseBytes(str string) (uint64, error) {
 
 	f = f * float64(m)
 	if f >= math.MaxUint64 {
-		return 0, errors.New("number of bytes too large")
+		return 0, errors.New(tr.Tr.Get("number of bytes too large"))
 	}
 	return uint64(f), nil
 }
@@ -86,7 +92,7 @@ func ParseByteUnit(str string) (uint64, error) {
 	if u, ok := bytesTable[str]; ok {
 		return u, nil
 	}
-	return 0, errors.Errorf("unknown unit: %q", str)
+	return 0, errors.New(tr.Tr.Get("unknown unit: %q", str))
 }
 
 var sizes = []string{"B", "KB", "MB", "GB", "TB", "PB"}
@@ -126,6 +132,38 @@ func FormatBytesUnit(s, u uint64) string {
 	return fmt.Sprintf(format, rounded)
 }
 
+// FormatByteRate outputs the given rate of transfer "r" as the quotient of "s"
+// (the number of bytes transferred) over "d" (the duration of time that those
+// bytes were transferred in).
+//
+// It displays the output as a quantity of a "per-unit-time" unit (i.e., B/s,
+// MiB/s) in the most representative fashion possible, as above.
+func FormatByteRate(s uint64, d time.Duration) string {
+	// e is the index of the most representative unit of storage.
+	var e float64
+
+	// f is the floating-point equivalent of "s", so as to avoid more
+	// conversions than necessary.
+	f := float64(s)
+
+	if f != 0 {
+		f = f / math.Max(time.Nanosecond.Seconds(), d.Seconds())
+		e = math.Floor(log(f, 1000))
+		if e <= eps {
+			// The result of math.Floor(log(r, 1000)) can be
+			// "close-enough" to zero that it should be effectively
+			// considered zero.
+			e = 0
+		}
+	}
+
+	unit := uint64(math.Pow(1000, e))
+	suffix := sizes[int(e)]
+
+	return fmt.Sprintf("%s %s/s",
+		FormatBytesUnit(uint64(math.Ceil(f)), unit), suffix)
+}
+
 // log takes the log base "b" of "n" (\log_b{n})
 func log(n, b float64) float64 {
 	return math.Log(n) / math.Log(b)
