@@ -6,14 +6,6 @@ import (
 	"github.com/stretchr/testify/assert"
 )
 
-func TestMinIntPicksTheSmallerInt(t *testing.T) {
-	assert.Equal(t, -1, MinInt(-1, 1))
-}
-
-func TestMaxIntPicksTheBiggertInt(t *testing.T) {
-	assert.Equal(t, 1, MaxInt(-1, 1))
-}
-
 func TestClampDiscardsIntsLowerThanMin(t *testing.T) {
 	assert.Equal(t, 0, ClampInt(-1, 0, 1))
 }
